Learn R Programming

biglars (version 1.0.1)

diabetes: Blood and other measurements in diabetics

Description

The diabetes1 data frame has 442 rows and 1 columns. These are the data used in the Efron et al "Least Angle Regression" paper.

The diabetes data frame has 442 rows and 3 matrices, containing predictors, response, and interactions.

Arguments

source

http://www-stat.stanford.edu/~hastie/Papers/LARS/LeastAngle_2002.ps

Details

The x matrix is standardized to have unit L2 norm in each column and zero mean. The matrix x2 consists of x plus second-order powers and interactions, also standardized.

References

B. Efron and T. Hastie (2003), "LARS software for R and Splus", http://www-stat.stanford.edu/~hastie/Papers/LARS

B. Efron, T. Hastie, I. Johnstone and R. Tibshirani (2004), "Least Angle Regression" (with discussion), Annals of Statistics 32, 407-499.

Examples

Run this code
data(diabetes)

stepFit <- biglars.fit(diabetes$x, diabetes$y, type = "stepwise")
stepFitBlocked <- biglars.fit(diabetes$x, diabetes$y, type = "stepwise",
                           blockSize = 50)

lassoFit <- biglars.fit(diabetes$x, diabetes$y)
lassoFitBlocked <- biglars.fit(diabetes$x, diabetes$y, blockSize = 34)

Run the code above in your browser using DataLab